searchData={"items":[{"type":"module","title":"Kino.VegaLite","doc":"A kino wrapping [VegaLite](https://hexdocs.pm/vega_lite) graphic.\n\nThis kino allow for rendering regular VegaLite graphic and then\nstreaming new data points to update the graphic.","ref":"Kino.VegaLite.html"},{"type":"module","title":"Examples - Kino.VegaLite","doc":"chart =\n      Vl.new(width: 400, height: 400)\n      |> Vl.mark(:line)\n      |> Vl.encode_field(:x, \"x\", type: :quantitative)\n      |> Vl.encode_field(:y, \"y\", type: :quantitative)\n      |> Kino.VegaLite.render()\n\n    for i <- 1..300 do\n      point = %{x: i / 10, y: :math.sin(i / 10)}\n      Kino.VegaLite.push(chart, point)\n      Process.sleep(25)\n    end","ref":"Kino.VegaLite.html#module-examples"},{"type":"function","title":"Kino.VegaLite.clear/2","doc":"Removes all data points from the graphic dataset.","ref":"Kino.VegaLite.html#clear/2"},{"type":"function","title":"Options - Kino.VegaLite.clear/2","doc":"* `dataset` - name of the targeted dataset from\n    the VegaLite specification. Defaults to the default\n    anonymous dataset","ref":"Kino.VegaLite.html#clear/2-options"},{"type":"function","title":"Kino.VegaLite.configure/1","doc":"Applies global configuration options for the VegaLite kinos.","ref":"Kino.VegaLite.html#configure/1"},{"type":"function","title":"Options - Kino.VegaLite.configure/1","doc":"* `:theme` - the theme to be applied on the rendered VegaLite\n    charts. Currently the only supported theme is `:livebook`. If\n    set to `nil`, no theme is applied. Defaults to `:livebook`.","ref":"Kino.VegaLite.html#configure/1-options"},{"type":"function","title":"Kino.VegaLite.new/1","doc":"Creates a new kino with the given VegaLite definition.","ref":"Kino.VegaLite.html#new/1"},{"type":"function","title":"Kino.VegaLite.periodically/4","doc":"Registers a callback to run periodically in the kino process.\n\nThe callback is run every `interval_ms` milliseconds and receives\nthe accumulated value. The callback should return either of:\n\n  * `{:cont, acc}` - the continue with the new accumulated value\n\n  * `:halt` - to no longer schedule callback evaluation\n\nThe callback is run for the first time immediately upon registration.","ref":"Kino.VegaLite.html#periodically/4"},{"type":"function","title":"Kino.VegaLite.push/3","doc":"Appends a single data point to the graphic dataset.","ref":"Kino.VegaLite.html#push/3"},{"type":"function","title":"Options - Kino.VegaLite.push/3","doc":"* `:window` - the maximum number of data points to keep.\n    This option is useful when you are appending new\n    data points to the plot over a long period of time\n\n  * `dataset` - name of the targeted dataset from\n    the VegaLite specification. Defaults to the default\n    anonymous dataset","ref":"Kino.VegaLite.html#push/3-options"},{"type":"function","title":"Kino.VegaLite.push_many/3","doc":"Appends a number of data points to the graphic dataset.\n\nSee `push/3` for more details.","ref":"Kino.VegaLite.html#push_many/3"},{"type":"function","title":"Kino.VegaLite.render/1","doc":"Renders and returns a new kino with the given VegaLite definition.\n\nIt is equivalent to:\n\n    vega_lite |> Kino.VegaLite.new() |> Kino.render()","ref":"Kino.VegaLite.html#render/1"},{"type":"function","title":"Kino.VegaLite.set_param/3","doc":"Updates a vega-lite [parameter's](https://vega.github.io/vega-lite/docs/parameter.html#variable-parameters) value.\n\nThe parameter must be registered: `VegaLite.param(vl, \"param_name\", opts)`.\n\nTo use the parameter in the chart, set a property to `[expr: \"param_name\"]`.","ref":"Kino.VegaLite.html#set_param/3"},{"type":"function","title":"Examples - Kino.VegaLite.set_param/3","doc":"chart =\n      VegaLite.new(width: 400, height: 400)\n      |> VegaLite.param(\"stroke_width\", value: 3)\n      |> VegaLite.mark(:line, stroke_width: [expr: \"stroke_width\"])\n      |> VegaLite.encode_field(:x, \"x\", type: :quantitative)\n      |> VegaLite.encode_field(:y, \"y\", type: :quantitative)\n      |> Kino.VegaLite.new()\n      |> Kino.render()\n\n    Kino.VegaLite.set_param(chart, \"stroke_width\", 10)","ref":"Kino.VegaLite.html#set_param/3-examples"},{"type":"type","title":"Kino.VegaLite.t/0","doc":"","ref":"Kino.VegaLite.html#t:t/0"},{"type":"extras","title":"Components","doc":"# Components\n\n```elixir\nMix.install([\n  {:vega_lite, \"~> 0.1.6\"},\n  {:kino_vega_lite, \"~> 0.1.9\"}\n])\n\nalias VegaLite, as: Vl\n```","ref":"components.html"},{"type":"extras","title":"Kinos - Components","doc":"","ref":"components.html#kinos"},{"type":"extras","title":"VegaLite - Components","doc":"This integration automatically renders the `VegaLite` struct as a chart:\n\n```elixir\nVl.new()\n|> Vl.data_from_values(iteration: 1..100, score: 1..100)\n|> Vl.mark(:line)\n|> Vl.encode_field(:x, \"iteration\", type: :quantitative)\n|> Vl.encode_field(:y, \"score\", type: :quantitative)\n```","ref":"components.html#vegalite"},{"type":"extras","title":"Kino.VegaLite - Components","doc":"`Kino.VegaLite` allows you to wrap an empty graphic and then stream\ndata to the chart:\n\n```elixir\nchart =\n  Vl.new(width: 400, height: 400)\n  |> Vl.mark(:line)\n  |> Vl.encode_field(:x, \"x\", type: :quantitative)\n  |> Vl.encode_field(:y, \"y\", type: :quantitative)\n  |> Kino.VegaLite.new()\n  |> Kino.render()\n\nfor i <- 1..300 do\n  point = %{x: i / 10, y: :math.sin(i / 10)}\n  Kino.VegaLite.push(chart, point)\n  Process.sleep(25)\nend\n```","ref":"components.html#kino-vegalite"},{"type":"extras","title":"Smart cells - Components","doc":"The following Smart cells are available:\n\n* **Chart cell** - for building visualizations for tabular data","ref":"components.html#smart-cells"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}